@@ -19,20 +19,34 @@ class ContactHandler:
 		for c in self.contacts:
 			#print c.get_name(), c.get_property('mobile-phone')
 			#print c.get_property('other-phone')
+			# this was a pretty clean solution as well, but oh so wrong!
 			mb = c.get_property('mobile-phone')
 			cp = c.get_property('other-phone')
-			self.phonedict[c.get_name()] = (mb, cp)
+			nrlist = (mb, cp)
+			fname =	c.get_name()
+			# TODO: this is _really_ slow... look at integration with c please
+			#nrlist = self.get_numbers_from_name(fname)
+			self.phonedict[c.get_name()] = nrlist
 	
 	""" returns all the numbers from a name, as a list """
-	def get_numbers_from_name(self, name):
-		search = self.ab.search(name)
+	def get_numbers_from_name(self, fname):
+		search = self.ab.search(fname)
 		res = search[0]
-		props = ['assistant-phone', 'business-phone', 'business-phone-2', 'callback-phone', 'car-phone', 'company-phone', 'home-phone', 'home-phone-2', 'mobile-phone', 'other-phone', 'primary-phone']
+		# would've been nice if this got all numbers, but alas, it dont.
+		"""props = ['assistant-phone', 'business-phone', 'business-phone-2', 'callback-phone', 'car-phone', 'company-phone', 'home-phone', 'home-phone-2', 'mobile-phone', 'other-phone', 'primary-phone']
 		nrlist = []
 		for p in props:
 			nr = res.get_property(p)
 			if nr != None:
-				nrlist.append(nr)
+				nrlist.append(nr)"""
+		# creative use of processing power? *cough*
+		nrlist = []
+		vcardlist = res.get_vcard_string().replace('\r', '').split('\n')
+		for line in vcardlist:
+			if line.startswith("TEL;"):
+				nr = line.split(":")[1]
+				if nr != None:
+					nrlist.append(nr)
 		return nrlist
 		
 	
@@ -91,18 +105,21 @@ class ContactHandler:
 if __name__ == '__main__':
 	cb = ContactHandler()
 	phonedict = {}
-	
-	#print cb.get_numbers_from_name('')
+	print cb.get_name_from_number("0730354431")
+	#print cb.ab.get_all_contacts()[0].__doc__
 	#asd = cb.get_contacts_as_list()
 	#print asd
 	
-	"""r = cb.ab.search('') # Returns List of results
+	"""r = cb.ab.search('Tom Le') # Returns List of results
 	print r
 	l = [x.get_name() for x in r] # list of results
 	u = r[0].get_name() # name of the first result
 	vcardlist = r[0].get_vcard_string().replace('\r', '').split('\n') # vcard for first result
+	#print vcardlist"""
+	#print cb.get_numbers_from_name('')
+	"""
 	for line in vcardlist:
-		if line.startswith("PHOTO;VALUE=uri:file://"):
-			print line.replace("PHOTO;VALUE=uri:file://", "")
-			
-	#print r[0].get_photo(64)"""
+		if not line.startswith("PHOTO"):
+			print line
+	"""
+	#print r[0].get_photo(64)
